#
# spec file for package normaliz
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           normaliz
Version:        3.5.4
Release:        lp150.1.1
Summary:        Tools for computations in affine monoids and rational cones
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
Url:            https://www.normaliz.uni-osnabrueck.de/

Source:         https://github.com/Normaliz/Normaliz/releases/download/v%version/%name-%version.tar.gz
BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.6
#maybe with flint-devel later on
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Normaliz is an open source tool for computations in affine monoids,
vector configurations, lattice polytopes, and rational cones.

Computation goals

* convex hulls and dual cones
* conversion from generators to constraints and vice versa
* triangulations, disjoint decompositions and Stanley decompositions
* Hilbert basis of rational, not necessarily pointed cones
* normalization of affine monoids
* lattice points of rational polytopes and (unbounded) polyhedra
* Hilbert (or Ehrhart) series and (quasi) polynomials under
  Z-gradings (for example, for rational polytopes)
* generalized (or weighted) Ehrhart series and Lebesgue integrals of
  polynomials over rational polytopes via NmzIntegrate

%package -n libnormaliz0
Summary:        C++ API for Normaliz, a tool for computation of rotational cones
Group:          System/Libraries

%description -n libnormaliz0
Normaliz is an open source tool for computations in affine monoids,
vector configurations, lattice polytopes, and rational cones.

Normaliz offers an API - libnormaliz - that allows the user to access
the Normaliz computations from any C++ program.

%package devel
Summary:        Development files for Normaliz, a tool for computation of rotational cones
Group:          Development/Libraries/C and C++
Requires:       boost-devel
Requires:       gmp-devel
Requires:       libnormaliz0 = %version

%description devel
Normaliz is an open source tool for computations in affine monoids,
vector configurations, lattice polytopes, and rational cones.

Normaliz offers an API - libnormaliz - that allows the user to access
the Normaliz computations from any C++ program.

%prep
%setup -q

%build
pushd source/
%cmake
make %{?_smp_mflags}
popd

%install
pushd source/
%cmake_install
popd

%post   -n libnormaliz0 -p /sbin/ldconfig
%postun -n libnormaliz0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/normaliz
%license source/COPYING

%files -n libnormaliz0
%defattr(-,root,root)
%_libdir/libnormaliz.so.*

%files devel
%defattr(-,root,root)
%_includedir/libnormaliz/
%_libdir/libnormaliz.so

%changelog
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 3.5.4:
  * Make computations that so far required homogeneous input
    available to all polytopes, regardless of the input type:
    Ehrhart series, triangulations, cone decomposition, Stanley
    decomposition.
- Changes from version 3.5.3:
  * Performance improvements.
  * Bug fixes.
- Changes from version 3.5.2:
  * Introduce a new algorithm for volume computations by descent
    in the face lattice.
  * Bug fixes.
- Use %%%%license to package COPYING file, instead of %%%%doc.
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 3.5.1:
  * Uniqueness in output of not uniqely determined results (bases
    of sublattices, equations), necessary to make all tests yield
    the same results on all.
  systems
- Drop 0001-Fix-compiler-warnings-in-matrix.cpp.patch:
  incorporated upstream.
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 3.5.0
  * Euclidean volume of polytopes
  * Expansion of series
  * Projection of cones and polyhedra
  * LLL reduced coordinates for project-and-lift
- Add 0001-Fix-compiler-warnings-in-matrix.cpp.patch
* Wed Nov 22 2017 badshah400@gmail.com
- Update to version 3.4.1:
  * Miscellaneous bug fixes.
* Wed Sep 27 2017 jengelh@inai.de
- Let normaliz-devel require boost-devel because its
  header files do.
* Mon Sep 25 2017 jengelh@inai.de
- Drop unusual Require on gap-core (copy&paste error?)
* Sat Aug 26 2017 badshah400@gmail.com
- Update to version 3.4.0:
  * New project-and-lift algorithm, also in a floating point
    variant.
  * Improved subdivision of large simplicial cones, equivalent own
    replacement of Scip.
  * Floating point input (and, partly, output).
  * Fast Gorenstein test.
  * Restriction of number of significant coefficients of
    quasipolynomial.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to new upstream release 3.3.0:
  * Inclusion of NmzIntegrate in libnormaliz
  * Rational numbers in input
  * Improvement of polynomial arithmetic
  * Controlled interruption
* Thu Mar 23 2017 jengelh@inai.de
- Update to new upstream release 3.2.1
  * Automatic choice of symmetrization
  * better use of HSOP option via libnormaliz
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 3.2.0
  * Constriants in symbolic format
  * A better implementation of Approximate and its use in the
    inhomogeneous case
  * Option for Symmetrize that produces symmetrized input for and
    runs nmzIntegrate and runs on it
  * QNormaliz, a version of Normaliz using coordinates in an
    extension of the rational numbers (estricted to convex hull
    computations and triangulation)
  * Further automatic choices of algorithmic variants
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 3.1.1
  * support for nonpointed cones / input of subspace
  * new computation goals: IsIntegrallyClosed and
  WitnessNotIntegrallyClosed
  * new computation goal: IntegerHull
  * new computation goal: ConeDecomposition
* Sat Mar 12 2016 jengelh@inai.de
- Initial package (version 3.1.0) for build.opensuse.org
